@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5129 $
+//  $Revision: 5344 $
 //
-//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
+//  $LastChangedDate: 2014-05-01 14:23:38 -0700 (Thu, 01 May 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -57,7 +57,9 @@ cmtk::DetectPhantomMagphanEMR051::DetectPhantomMagphanEMR051( UniformVolume::Sma
     m_IncludeMask( phantomImage->CloneGrid() )
 {
   this->m_ExcludeMask->CreateDataArray( TYPE_BYTE, true /*setToZero*/ );
+  this->m_ExcludeMask->GetData()->SetDataClass( DATACLASS_LABEL );
   this->m_IncludeMask->CreateDataArray( TYPE_BYTE );
+  this->m_IncludeMask->GetData()->SetDataClass( DATACLASS_LABEL );
 
   this->m_Landmarks.resize( MagphanEMR051::NumberOfSpheres );
 
@@ -131,7 +133,7 @@ cmtk::DetectPhantomMagphanEMR051::DetectPhantomMagphanEMR051( UniformVolume::Sma
 
     // Use the phantom center estimate with the smallest angle cosine, i.e., the one generating the closest to an orthogonal coordinate system
     Types::Coordinate minAngleCosine;
-    if ( angleCosineSNR <= angleCosineCNR )
+    if ( (angleCosineSNR <= angleCosineCNR) && !this->m_Parameters.m_ForceFallbackCentroidCNR )
       {
       minAngleCosine = angleCosineSNR;
       phantomCenter = this->m_Landmarks[0].m_Location;
@@ -567,6 +569,12 @@ cmtk::DetectPhantomMagphanEMR051::RefineSphereLocation( const Self::SpaceVectorT
       {
       regionVolume->SetData( LeastSquaresPolynomialIntensityBiasField( *regionVolume, regionMaskVectorErode, 1 /* polynomial degree */ ).GetCorrectedData() );
       }
+    catch ( PolynomialHelper::DegreeUnsupported& ex )
+      {
+      StdErr << "ERROR: polynomial degree not supported in LeastSquaresPolynomialIntensityBiasField() constructor.\n";
+      StdErr << ex.what() << "\n";
+      throw ExitException( 1 );
+      }
     catch ( const LeastSquaresPolynomialIntensityBiasField::EmptyMaskException& )
       {
       // nothing to do; regionVolume still has its data
@@ -716,6 +724,12 @@ cmtk::DetectPhantomMagphanEMR051::GetSphereMeanStdDeviation( Types::DataItem& me
       {
       dataArray = LeastSquaresPolynomialIntensityBiasField( *dataVolume, regionMaskVector, biasFieldDegree ).GetCorrectedData();
       }
+    catch ( PolynomialHelper::DegreeUnsupported& ex )
+      {
+      StdErr << "ERROR: polynomial degree not supported in LeastSquaresPolynomialIntensityBiasField() constructor.\n";
+      StdErr << ex.what() << "\n";
+      throw ExitException( 1 );
+      }
     catch ( const LeastSquaresPolynomialIntensityBiasField::EmptyMaskException& )
       {
       // dataArray should still be the original data, but doesn't hurt to assign again, just in case.
